"""
    WhyLabs API client

    WhyLabs API that enables end-to-end AI observability  # noqa: E501

    The version of the OpenAPI document: 0.1
    Contact: support@whylabs.ai
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from whylabs_client.api_client import ApiClient, Endpoint as _Endpoint
from whylabs_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from whylabs_client.model.column_schema import ColumnSchema
from whylabs_client.model.entity_schema import EntitySchema
from whylabs_client.model.list_models_response import ListModelsResponse
from whylabs_client.model.metric_schema import MetricSchema
from whylabs_client.model.model_metadata_response import ModelMetadataResponse
from whylabs_client.model.model_type import ModelType
from whylabs_client.model.response import Response
from whylabs_client.model.time_period import TimePeriod


class ModelsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_model_endpoint = _Endpoint(
            settings={
                'response_type': (ModelMetadataResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models',
                'operation_id': 'create_model',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'model_name',
                    'time_period',
                    'model_type',
                    'model_id',
                ],
                'required': [
                    'org_id',
                    'model_name',
                    'time_period',
                ],
                'nullable': [
                    'model_id',
                ],
                'enum': [
                ],
                'validation': [
                    'org_id',
                    'model_name',
                    'model_id',
                ]
            },
            root_map={
                'validations': {
                    ('org_id',): {
                        'max_length': 128,
                    },
                    ('model_name',): {
                        'max_length': 512,
                        'min_length': 4,
                    },
                    ('model_id',): {
                        'max_length': 128,
                        'min_length': 4,
                        'regex': {
                            'pattern': r'^[0-9a-zA-Z_-]+$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'model_name':
                        (str,),
                    'time_period':
                        (TimePeriod,),
                    'model_type':
                        (ModelType,),
                    'model_id':
                        (str, none_type,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'model_name': 'model_name',
                    'time_period': 'time_period',
                    'model_type': 'model_type',
                    'model_id': 'model_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'model_name': 'query',
                    'time_period': 'query',
                    'model_type': 'query',
                    'model_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.deactivate_model_endpoint = _Endpoint(
            settings={
                'response_type': (ModelMetadataResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{model_id}',
                'operation_id': 'deactivate_model',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'model_id',
                ],
                'required': [
                    'org_id',
                    'model_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'model_id':
                        (str,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'model_id': 'model_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'model_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_entity_schema_endpoint = _Endpoint(
            settings={
                'response_type': (Response,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{dataset_id}/schema',
                'operation_id': 'delete_entity_schema',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'dataset_id',
                ],
                'required': [
                    'org_id',
                    'dataset_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'dataset_id':
                        (str,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'dataset_id': 'dataset_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'dataset_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_entity_schema_column_endpoint = _Endpoint(
            settings={
                'response_type': (Response,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{dataset_id}/schema/column/{column_id}',
                'operation_id': 'delete_entity_schema_column',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'dataset_id',
                    'column_id',
                ],
                'required': [
                    'org_id',
                    'dataset_id',
                    'column_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'dataset_id':
                        (str,),
                    'column_id':
                        (str,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'dataset_id': 'dataset_id',
                    'column_id': 'column_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'dataset_id': 'path',
                    'column_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_entity_schema_metric_endpoint = _Endpoint(
            settings={
                'response_type': (Response,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{dataset_id}/schema/metric/{metric_label}',
                'operation_id': 'delete_entity_schema_metric',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'dataset_id',
                    'metric_label',
                ],
                'required': [
                    'org_id',
                    'dataset_id',
                    'metric_label',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'dataset_id':
                        (str,),
                    'metric_label':
                        (str,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'dataset_id': 'dataset_id',
                    'metric_label': 'metric_label',
                },
                'location_map': {
                    'org_id': 'path',
                    'dataset_id': 'path',
                    'metric_label': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_entity_schema_endpoint = _Endpoint(
            settings={
                'response_type': (EntitySchema,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{dataset_id}/schema',
                'operation_id': 'get_entity_schema',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'dataset_id',
                ],
                'required': [
                    'org_id',
                    'dataset_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'dataset_id':
                        (str,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'dataset_id': 'dataset_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'dataset_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_entity_schema_column_endpoint = _Endpoint(
            settings={
                'response_type': (ColumnSchema,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{dataset_id}/schema/column/{column_id}',
                'operation_id': 'get_entity_schema_column',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'dataset_id',
                    'column_id',
                ],
                'required': [
                    'org_id',
                    'dataset_id',
                    'column_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'dataset_id':
                        (str,),
                    'column_id':
                        (str,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'dataset_id': 'dataset_id',
                    'column_id': 'column_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'dataset_id': 'path',
                    'column_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_model_endpoint = _Endpoint(
            settings={
                'response_type': (ModelMetadataResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{model_id}',
                'operation_id': 'get_model',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'model_id',
                ],
                'required': [
                    'org_id',
                    'model_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'model_id':
                        (str,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'model_id': 'model_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'model_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_models_endpoint = _Endpoint(
            settings={
                'response_type': (ListModelsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models',
                'operation_id': 'list_models',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                ],
                'required': [
                    'org_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                },
                'location_map': {
                    'org_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.put_entity_schema_endpoint = _Endpoint(
            settings={
                'response_type': (Response,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{dataset_id}/schema',
                'operation_id': 'put_entity_schema',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'dataset_id',
                    'entity_schema',
                ],
                'required': [
                    'org_id',
                    'dataset_id',
                    'entity_schema',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'dataset_id':
                        (str,),
                    'entity_schema':
                        (EntitySchema,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'dataset_id': 'dataset_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'dataset_id': 'path',
                    'entity_schema': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_entity_schema_column_endpoint = _Endpoint(
            settings={
                'response_type': (Response,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{dataset_id}/schema/column/{column_id}',
                'operation_id': 'put_entity_schema_column',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'dataset_id',
                    'column_id',
                    'column_schema',
                ],
                'required': [
                    'org_id',
                    'dataset_id',
                    'column_id',
                    'column_schema',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'dataset_id':
                        (str,),
                    'column_id':
                        (str,),
                    'column_schema':
                        (ColumnSchema,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'dataset_id': 'dataset_id',
                    'column_id': 'column_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'dataset_id': 'path',
                    'column_id': 'path',
                    'column_schema': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_entity_schema_metric_endpoint = _Endpoint(
            settings={
                'response_type': (Response,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{dataset_id}/schema/metric',
                'operation_id': 'put_entity_schema_metric',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'dataset_id',
                    'metric_schema',
                ],
                'required': [
                    'org_id',
                    'dataset_id',
                    'metric_schema',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'dataset_id':
                        (str,),
                    'metric_schema':
                        (MetricSchema,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'dataset_id': 'dataset_id',
                },
                'location_map': {
                    'org_id': 'path',
                    'dataset_id': 'path',
                    'metric_schema': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.update_model_endpoint = _Endpoint(
            settings={
                'response_type': (ModelMetadataResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/v0/organizations/{org_id}/models/{model_id}',
                'operation_id': 'update_model',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'org_id',
                    'model_id',
                    'model_name',
                    'time_period',
                    'model_type',
                ],
                'required': [
                    'org_id',
                    'model_id',
                    'model_name',
                    'time_period',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'org_id':
                        (str,),
                    'model_id':
                        (str,),
                    'model_name':
                        (str,),
                    'time_period':
                        (TimePeriod,),
                    'model_type':
                        (ModelType,),
                },
                'attribute_map': {
                    'org_id': 'org_id',
                    'model_id': 'model_id',
                    'model_name': 'model_name',
                    'time_period': 'time_period',
                    'model_type': 'model_type',
                },
                'location_map': {
                    'org_id': 'path',
                    'model_id': 'path',
                    'model_name': 'query',
                    'time_period': 'query',
                    'model_type': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def create_model(
        self,
        org_id,
        model_name,
        time_period,
        **kwargs
    ):
        """Create a model with a given name and a time period  # noqa: E501

        Create a model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_model(org_id, model_name, time_period, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str): The organization ID
            model_name (str): The name of a model
            time_period (TimePeriod): The [TimePeriod] for data aggregation/alerting for a model

        Keyword Args:
            model_type (ModelType): The [ModelType] of the dataset. [optional]
            model_id (str, none_type): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ModelMetadataResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['model_name'] = \
            model_name
        kwargs['time_period'] = \
            time_period
        return self.create_model_endpoint.call_with_http_info(**kwargs)

    def deactivate_model(
        self,
        org_id,
        model_id,
        **kwargs
    ):
        """Mark a model as inactive  # noqa: E501

        Mark a model as inactive  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.deactivate_model(org_id, model_id, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str): The organization ID
            model_id (str): The model ID

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ModelMetadataResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['model_id'] = \
            model_id
        return self.deactivate_model_endpoint.call_with_http_info(**kwargs)

    def delete_entity_schema(
        self,
        org_id,
        dataset_id,
        **kwargs
    ):
        """Delete the entity schema config for a given dataset.  # noqa: E501

        Delete the entity schema config for a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_entity_schema(org_id, dataset_id, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str):
            dataset_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['dataset_id'] = \
            dataset_id
        return self.delete_entity_schema_endpoint.call_with_http_info(**kwargs)

    def delete_entity_schema_column(
        self,
        org_id,
        dataset_id,
        column_id,
        **kwargs
    ):
        """Delete the entity schema of a single column for a given dataset.  # noqa: E501

        Delete the entity schema of a single column for a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_entity_schema_column(org_id, dataset_id, column_id, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str):
            dataset_id (str):
            column_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['dataset_id'] = \
            dataset_id
        kwargs['column_id'] = \
            column_id
        return self.delete_entity_schema_column_endpoint.call_with_http_info(**kwargs)

    def delete_entity_schema_metric(
        self,
        org_id,
        dataset_id,
        metric_label,
        **kwargs
    ):
        """Delete the schema of a single metric for a given dataset.  # noqa: E501

        Delete the schema of a single metric for a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_entity_schema_metric(org_id, dataset_id, metric_label, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str):
            dataset_id (str):
            metric_label (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['dataset_id'] = \
            dataset_id
        kwargs['metric_label'] = \
            metric_label
        return self.delete_entity_schema_metric_endpoint.call_with_http_info(**kwargs)

    def get_entity_schema(
        self,
        org_id,
        dataset_id,
        **kwargs
    ):
        """Get the entity schema config for a given dataset.  # noqa: E501

        Get the entity schema config for a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_entity_schema(org_id, dataset_id, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str):
            dataset_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            EntitySchema
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['dataset_id'] = \
            dataset_id
        return self.get_entity_schema_endpoint.call_with_http_info(**kwargs)

    def get_entity_schema_column(
        self,
        org_id,
        dataset_id,
        column_id,
        **kwargs
    ):
        """Get the entity schema of a single column for a given dataset.  # noqa: E501

        Get the entity schema of a single column for a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_entity_schema_column(org_id, dataset_id, column_id, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str):
            dataset_id (str):
            column_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ColumnSchema
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['dataset_id'] = \
            dataset_id
        kwargs['column_id'] = \
            column_id
        return self.get_entity_schema_column_endpoint.call_with_http_info(**kwargs)

    def get_model(
        self,
        org_id,
        model_id,
        **kwargs
    ):
        """Get a model metadata  # noqa: E501

        Returns various metadata about a model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_model(org_id, model_id, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str): The name of an organization
            model_id (str): The ID of a model

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ModelMetadataResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['model_id'] = \
            model_id
        return self.get_model_endpoint.call_with_http_info(**kwargs)

    def list_models(
        self,
        org_id,
        **kwargs
    ):
        """Get a list of all of the model ids for an organization.  # noqa: E501

        Get a list of all of the model ids for an organization.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_models(org_id, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str): Your company's unique organization ID

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ListModelsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        return self.list_models_endpoint.call_with_http_info(**kwargs)

    def put_entity_schema(
        self,
        org_id,
        dataset_id,
        entity_schema,
        **kwargs
    ):
        """Save the entity schema config for a given dataset.  # noqa: E501

        Save the entity schema config for a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_entity_schema(org_id, dataset_id, entity_schema, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str):
            dataset_id (str):
            entity_schema (EntitySchema):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['dataset_id'] = \
            dataset_id
        kwargs['entity_schema'] = \
            entity_schema
        return self.put_entity_schema_endpoint.call_with_http_info(**kwargs)

    def put_entity_schema_column(
        self,
        org_id,
        dataset_id,
        column_id,
        column_schema,
        **kwargs
    ):
        """Save the entity schema of a single column for a given dataset.  # noqa: E501

        Save the entity schema of a single column for a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_entity_schema_column(org_id, dataset_id, column_id, column_schema, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str):
            dataset_id (str):
            column_id (str):
            column_schema (ColumnSchema):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['dataset_id'] = \
            dataset_id
        kwargs['column_id'] = \
            column_id
        kwargs['column_schema'] = \
            column_schema
        return self.put_entity_schema_column_endpoint.call_with_http_info(**kwargs)

    def put_entity_schema_metric(
        self,
        org_id,
        dataset_id,
        metric_schema,
        **kwargs
    ):
        """Save the schema of a single metric for a given dataset.  # noqa: E501

        Save the schema of a single metric for a given dataset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_entity_schema_metric(org_id, dataset_id, metric_schema, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str):
            dataset_id (str):
            metric_schema (MetricSchema):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['dataset_id'] = \
            dataset_id
        kwargs['metric_schema'] = \
            metric_schema
        return self.put_entity_schema_metric_endpoint.call_with_http_info(**kwargs)

    def update_model(
        self,
        org_id,
        model_id,
        model_name,
        time_period,
        **kwargs
    ):
        """Update a model's metadata  # noqa: E501

        Update a model's metadata  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_model(org_id, model_id, model_name, time_period, async_req=True)
        >>> result = thread.get()

        Args:
            org_id (str): The organization ID
            model_id (str): The model ID
            model_name (str): The name of a model
            time_period (TimePeriod): The [TimePeriod] for data aggregation/alerting for a model

        Keyword Args:
            model_type (ModelType): The [ModelType] of the dataset. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ModelMetadataResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['org_id'] = \
            org_id
        kwargs['model_id'] = \
            model_id
        kwargs['model_name'] = \
            model_name
        kwargs['time_period'] = \
            time_period
        return self.update_model_endpoint.call_with_http_info(**kwargs)




"""
    WhyLabs API client

    WhyLabs API that enables end-to-end AI observability  # noqa: E501

    The version of the OpenAPI document: 0.1
    Contact: support@whylabs.ai
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "whylabs-client"
VERSION = "0.4.5"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
]

setup(
    name=NAME,
    version=VERSION,
    description="WhyLabs API client",
    author="WhyLabs",
    author_email="support@whylabs.ai",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "WhyLabs API client"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache License 2.0",
    long_description_content_type="text/markdown",
    long_description="""\
    WhyLabs API that enables end-to-end AI observability  # noqa: E501
    """
)



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from whylabs_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from whylabs_client.model.aws_marketplace_metadata import AWSMarketplaceMetadata
from whylabs_client.model.action_type import ActionType
from whylabs_client.model.add_membership_request import AddMembershipRequest
from whylabs_client.model.async_log_response import AsyncLogResponse
from whylabs_client.model.column_schema import ColumnSchema
from whylabs_client.model.create_session_request import CreateSessionRequest
from whylabs_client.model.create_session_response import CreateSessionResponse
from whylabs_client.model.create_user_request import CreateUserRequest
from whylabs_client.model.dto_auto_scale_dto import DTOAutoScaleDTO
from whylabs_client.model.dto_aws_attributes_dto import DTOAwsAttributesDTO
from whylabs_client.model.dto_aws_availability_dto import DTOAwsAvailabilityDTO
from whylabs_client.model.dto_cluster_log_conf_dto import DTOClusterLogConfDTO
from whylabs_client.model.dto_cron_schedule_dto import DTOCronScheduleDTO
from whylabs_client.model.dto_dbfs_storage_info_dto import DTODbfsStorageInfoDTO
from whylabs_client.model.dto_ebs_volume_type_dto import DTOEbsVolumeTypeDTO
from whylabs_client.model.dto_job_dto import DTOJobDTO
from whylabs_client.model.dto_job_email_notifications_dto import DTOJobEmailNotificationsDTO
from whylabs_client.model.dto_job_settings_dto import DTOJobSettingsDTO
from whylabs_client.model.dto_new_cluster_dto import DTONewClusterDTO
from whylabs_client.model.dto_notebook_task_dto import DTONotebookTaskDTO
from whylabs_client.model.dtos3_storage_info_dto import DTOS3StorageInfoDTO
from whylabs_client.model.dto_spark_jar_task_dto import DTOSparkJarTaskDTO
from whylabs_client.model.dto_spark_python_task_dto import DTOSparkPythonTaskDTO
from whylabs_client.model.dto_spark_submit_task_dto import DTOSparkSubmitTaskDTO
from whylabs_client.model.databricks_connection import DatabricksConnection
from whylabs_client.model.dataset_request_monitor_config import DatasetRequestMonitorConfig
from whylabs_client.model.datatype_monitor_request_config import DatatypeMonitorRequestConfig
from whylabs_client.model.delete_analyzer_results_response import DeleteAnalyzerResultsResponse
from whylabs_client.model.delete_dataset_profiles_response import DeleteDatasetProfilesResponse
from whylabs_client.model.distribution_monitor_request_config import DistributionMonitorRequestConfig
from whylabs_client.model.email_notification_action import EmailNotificationAction
from whylabs_client.model.entity_schema import EntitySchema
from whylabs_client.model.entity_weight_record import EntityWeightRecord
from whylabs_client.model.entity_weight_record_metadata import EntityWeightRecordMetadata
from whylabs_client.model.feature_flags import FeatureFlags
from whylabs_client.model.get_connection_request import GetConnectionRequest
from whylabs_client.model.get_connection_response import GetConnectionResponse
from whylabs_client.model.get_dataset_metadata_response import GetDatasetMetadataResponse
from whylabs_client.model.get_default_membership_response import GetDefaultMembershipResponse
from whylabs_client.model.get_marketplace_metadata_response import GetMarketplaceMetadataResponse
from whylabs_client.model.get_memberships_response import GetMembershipsResponse
from whylabs_client.model.get_monitor_config_v2_response import GetMonitorConfigV2Response
from whylabs_client.model.get_notification_settings_response import GetNotificationSettingsResponse
from whylabs_client.model.get_session_response import GetSessionResponse
from whylabs_client.model.list_jobs_request import ListJobsRequest
from whylabs_client.model.list_jobs_response import ListJobsResponse
from whylabs_client.model.list_models_response import ListModelsResponse
from whylabs_client.model.list_organization_memberships_response import ListOrganizationMembershipsResponse
from whylabs_client.model.list_user_api_keys import ListUserApiKeys
from whylabs_client.model.log_async_request import LogAsyncRequest
from whylabs_client.model.log_reference_request import LogReferenceRequest
from whylabs_client.model.log_reference_response import LogReferenceResponse
from whylabs_client.model.log_response import LogResponse
from whylabs_client.model.marketplace_dimensions import MarketplaceDimensions
from whylabs_client.model.membership import Membership
from whylabs_client.model.membership_metadata import MembershipMetadata
from whylabs_client.model.metric_schema import MetricSchema
from whylabs_client.model.missing_recent_data_request_config import MissingRecentDataRequestConfig
from whylabs_client.model.missing_recent_profiles_request_config import MissingRecentProfilesRequestConfig
from whylabs_client.model.missing_values_monitor_request_config import MissingValuesMonitorRequestConfig
from whylabs_client.model.model_metadata_response import ModelMetadataResponse
from whylabs_client.model.model_type import ModelType
from whylabs_client.model.monitor_config import MonitorConfig
from whylabs_client.model.monitor_config_version import MonitorConfigVersion
from whylabs_client.model.monitor_request_reference import MonitorRequestReference
from whylabs_client.model.monitor_request_reference_type import MonitorRequestReferenceType
from whylabs_client.model.notification_action import NotificationAction
from whylabs_client.model.notification_settings import NotificationSettings
from whylabs_client.model.notification_settings_day import NotificationSettingsDay
from whylabs_client.model.notification_sqs_message_cadence import NotificationSqsMessageCadence
from whylabs_client.model.organization_metadata import OrganizationMetadata
from whylabs_client.model.organization_summary import OrganizationSummary
from whylabs_client.model.pager_duty_notification_action import PagerDutyNotificationAction
from whylabs_client.model.provided_config import ProvidedConfig
from whylabs_client.model.provision_databricks_connection_request import ProvisionDatabricksConnectionRequest
from whylabs_client.model.provision_databricks_connection_response import ProvisionDatabricksConnectionResponse
from whylabs_client.model.provision_new_aws_marketplace_user_response import ProvisionNewAWSMarketplaceUserResponse
from whylabs_client.model.provision_new_marketplace_user_request import ProvisionNewMarketplaceUserRequest
from whylabs_client.model.provision_new_user_request import ProvisionNewUserRequest
from whylabs_client.model.provision_new_user_response import ProvisionNewUserResponse
from whylabs_client.model.reference_profile_item_response import ReferenceProfileItemResponse
from whylabs_client.model.refresh_access_token_request import RefreshAccessTokenRequest
from whylabs_client.model.refresh_connection_by_org_id_response import RefreshConnectionByOrgIdResponse
from whylabs_client.model.refresh_connection_request import RefreshConnectionRequest
from whylabs_client.model.register_databricks_connection_request import RegisterDatabricksConnectionRequest
from whylabs_client.model.register_databricks_connection_response import RegisterDatabricksConnectionResponse
from whylabs_client.model.remove_membership_request import RemoveMembershipRequest
from whylabs_client.model.request_feature_monitor_config import RequestFeatureMonitorConfig
from whylabs_client.model.request_monitor_config import RequestMonitorConfig
from whylabs_client.model.response import Response
from whylabs_client.model.role import Role
from whylabs_client.model.run_job_request import RunJobRequest
from whylabs_client.model.run_job_response import RunJobResponse
from whylabs_client.model.schema_metadata import SchemaMetadata
from whylabs_client.model.seasonal_arima_request_config import SeasonalARIMARequestConfig
from whylabs_client.model.segment import Segment
from whylabs_client.model.segment_tag import SegmentTag
from whylabs_client.model.segment_weight import SegmentWeight
from whylabs_client.model.session_metadata import SessionMetadata
from whylabs_client.model.set_default_membership_request import SetDefaultMembershipRequest
from whylabs_client.model.slack_notification_action import SlackNotificationAction
from whylabs_client.model.subscription_tier import SubscriptionTier
from whylabs_client.model.time_period import TimePeriod
from whylabs_client.model.uber_notification_schedule import UberNotificationSchedule
from whylabs_client.model.unique_values_monitor_request_config import UniqueValuesMonitorRequestConfig
from whylabs_client.model.update_connection_changes import UpdateConnectionChanges
from whylabs_client.model.update_connection_request import UpdateConnectionRequest
from whylabs_client.model.update_membership_request import UpdateMembershipRequest
from whylabs_client.model.user import User
from whylabs_client.model.user_api_key import UserApiKey
from whylabs_client.model.user_api_key_response import UserApiKeyResponse
from whylabs_client.model.why_logs_metric import WhyLogsMetric
